#
# spec file for package hourglass
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.github.sgpthomas.hourglass
Name:           hourglass
Version:        3.1.0
Release:        1.2
Summary:        Clock gadget for the Pantheon DE
License:        GPL-3.0-only
URL:            https://github.com/sgpthomas/hourglass
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson >= 0.57.0
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.28
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(granite-7) >= 7.1.0
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libportal-gtk4)

%description
A clock application that is designed to fit perfectly into
Pantheon's design scheme.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}

#fix upstream
chmod -x %{buildroot}%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
chmod -x %{buildroot}%{_datadir}/pixmaps/%{appid}.svg

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/metainfo/%{appid}.metainfo.xml
%{_datadir}/pixmaps/%{appid}.svg

%files lang -f %{appid}.lang

%changelog
* Mon Nov 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 3.1.0:
  * Use portal for background and autostart
  * Update translations
- update to 3.0.0:
  * Port to GTK 4
  * Ctrl+S to toggle stopwatch
  * Correct license in the app metainfo
  * Update translations
- update to 2.0.4:
  * Improve relative time handling
- update to 2.0.3:
  * Add additional categories other than ambiguous Utility in the desktop entry
  * Show the window in the center of the display at the first launch
  * Make styling more consistent between stopwatch and timer
  * Ring alarms only on repeated days
  * Fix the condition of closing the app window being reversed
  * Update translations
- update spec file for Leap 16.0:
  * rework make dependencies, as a lot changed for the last 3y
  * remove mentioning of elementary
  * remove %%suse_update_desktop_file
* Sat Nov 20 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.0.2:
  * Fix a regression that the app don't launch if you create a
    repeated alarm, close the app, and try to reopen it
  * AlarmView: Organize displayed information
- This release contains small bug fixes and improvements:
  * Strict on sandbox permission
  * Rounded window corners and flat titlebar
  * NewAlarmDialog: Add placeholder text for title entry
  * Set shorter summary text in appdata
  * Use palette of elementary for branding color
  * Make sure to select an alarm on removing/adding/editing it
    and startup
  * Clean code
* Thu Sep  9 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.0.0:
  * This release comes with numerous bug fixes &amp;
    improvements!
- Changes in Alarm:
  * Refresh weekday toggle activity when opening popover
  * Notify on every 0 second
  * Keep repeated alarms on and turn off one-time alarms after
    ringing
  * Now alarm date is optional; if you don't specify date of the
    alarm, it will be notified at that time of today
  * Remove unused "update-frequency" gsettings key
  * Fix repeating alarms can't be disabled
  * Explicitly set the year
- Changes in Timer:
  * Add Reset button
  * Support setting purpose of a timer
  * Lessen damages to your storage
  * Restore started time on end
  * Make sure to iconify always when the timer is active
- Other changes:
  * Fix a regression that any key input no longer accepted
  * Lessen window width by default
  * Fix the app exits if the window has been iconified
  * Code refactoring
  * Update translations
  * Publish the app to the new AppCenter on elementary OS 6 with
    the Flatpak manifest
  * Respect an elementary OS-wide dark preference
  * Now you can close the window with the shortcut key Ctrl+Q,
    while the daemon stays running in the background
  * Fix unreadable font size in the Alarm view
  * Fix wrong OARS data
  * Move the delete button in the action bar
  * Redesign app icons (big thanks to @Fatih20)
  * Update Brazilian Portuguese translation (by @gfavaro)
* Sun Oct 11 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.2.3:
  * StopWatch: Rewrite for efficiency and visibility
  * Add :disabled pseudo-class to the .round-button class
  * Fix a fatal regression that timer does not stop on 00:00:00
  * Use icons for add/remove buttons
  * Update .desktop comment to be consistent with HIG (by
    @aljelly)
  * Change shortened format of weekdays (by @NathanBnm)
  * Improve look of create/edit alarm dialog
  * Don't reset repeat setting on closing popover
  * Fix DBus error at the first launch
  * Fix notification icon is not set
  * Fix left time shows unexpected values if set time is too big
  * Improve saving window state
  * Add French translation (by @NathanBnm)
  * Update Spanish translation (by @CCaroV)
  * Add Japanese translation
  * Add Portuguese-Portugal translation (by @rottenpants466)
  * Various l10n and coding improvements to the project thanks to
    @NathanBnm
* Thu Apr 30 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.2.1:
  * Merge pull request #58 from ryonakano/add-meson
  * Remove no longer used config data element
  * Use GResource to load CSS
  * README: Add installation instruction
  * Tweak line breaks
  * DRY meson project name
  * Remove unnecessary files
  * Remove overkilling or unnecessary configs/files
  * Complete RDNN
  * Revert unwanted change
  * Tab to 4 spaces
  * Add meson
  * fixed the notification going off again when you open the app
  * Merge branch 'master' of github.com:sgpthomas/hourglass
  * fixed what happens when the app closes and there is a timer
    running
  * Merge pull request #45 from danrabbit/patch-1
  * Remove "." from appdata summary
  * Merge pull request #41 from Allen-B1/patch-1
  * Add the Get it on AppCenter button
  * hourglass finally knows how to keep time, closes #34
  * Merge pull request #39 from welaq/master
  * Added Lithuanian to .desktop
  * Added Lithuanian comment
  * fixed #35 by disallowing multiple windows
- Switch to meson
- Spec file cleanup
* Fri Nov 10 2017 avvissu@yandex.by
- Update to 1.1.1:
  * Made the alarm noise persist until you close the notification
  * Added some margin to the repeat day label
- Switch from bzr to git
- Add AppData file
- Spec file cleanup
* Tue Jun 13 2017 jengelh@inai.de
- Ensure neutrality of description.
* Wed May 10 2017 avvissu@yandex.by
- Update to stable release 1.0.1
- Specfile cleanup
* Sun Mar  6 2016 and.november@opensuse.org
- initial package (version 1.0.1) for openSUSE
